%%% Monte Carlo Dynamic Classifier tool - MCDC tool
% http://www.ismvideo.org/NDE0UP/MCDCtool/en/index.html

% Copyright (C) 2014 Gareth W. Peters, Tomoko Matsui, Francois Septier, and Akira Tamamori

% This program is free software; you can redistribute it and/or modify it under the terms
% of the GNU General Public License as published by the Free Software Foundation; either
% version 2 of the License, or (at your option) any later version.

% This program is distributed in the hope that it will be useful, but WITHOUT ANY
% WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE.  See the GNU General Public License for more details.

% You should have received a copy of the GNU General Public License along with this
% program; if not, see <http://www.gnu.org/licenses/>.

%
% RBFKernel.m
%
classdef RBFKernel < Kernel
  
  properties (SetAccess = private)
    Sigma
    L
  end
  
  methods (Access = public)
  
    function this = RBFKernel(sigma, l)
      this.Sigma = sigma;
      this.L = l;
    end
    
    function result = Properties(this)
      result = [this.Sigma; this.L];
    end
    
    function result = CreateGramMatrix(this, xGrid)
      l = size(xGrid, 2);
      s = eye(size(xGrid, 1)) * this.L; % SIGMA?
      xGridT = xGrid';
      result = this.Sigma ^ 2 * cell2mat(arrayfun(@(i) (mvnpdf(xGridT, xGridT(i,:), s)), 1:l, 'UniformOutput', false));
    end
    
    function result = ToString(this)
      result = sprintf('[ Sigma=%f, L=%f ]', this.Sigma, this.L);
    end
    
  end
  
end
